..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Developer Guide
===============

In the Developer Guide, you will find information on the design and
implementation of Group Based Policy's software components.


Programming HowTos and Tutorials
--------------------------------
.. toctree::
    :maxdepth: 3

    development.environment


GBP Design
----------
.. toctree::
   :maxdepth: 3

   abstraction
   development.environment
   extension-drivers
   external-connectivity
   floating-ip-support
   group-policy-apic-driver
   heat-support
   images
   odl-policy-driver
   policy-target-cluster-id
   service-chain-abstractions
   service-chain-driver
   shared-resources
   traffic-stitching-plumber-model
   traffic-stitching-plumber-placement-type
   apic-aim-ml2-driver

Module Reference
----------------
.. toctree::
   :maxdepth: 3

.. todo::

    Add in all the big modules as automodule indexes.


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
